package pro.litvinovg.w2phtml.gui;

import java.awt.Component;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;

import com.sun.star.uno.XComponentContext;

public class ConfigurationReader {
	
	HashMap<String,String> options = new HashMap<String,String>();
	private XComponentContext context;
	private String format = null;
	private String inputFilePath = null;
	private String outputFilePath = null;
	private String metadataFilePath = null;
	private JFrame frame;

	public ConfigurationReader(HashMap<String, Component> configuration, XComponentContext context, JFrame frame) {
		this.context = context;
		this.frame = frame;
		readOptions(configuration);
	}

	private void readOptions(HashMap<String, Component> configuration) {
		Set<String> keys = configuration.keySet();
		for (String optionName : keys) {
			String optionValue = null;
			Component component = configuration.get(optionName);
			if (component.getClass().equals(JTextField.class)) {
				optionValue = ((JTextField) component).getText();
			} else if (component.getClass().equals(JCheckBox.class)) {
				optionValue = Boolean.toString(((JCheckBox) component).isSelected());
			} else if (component.getClass().equals(JLabel.class)) {
				optionValue = ((JLabel) component).getText();
			}
			options.put(optionName, optionValue);

		}
		format = options.get("targetFormat");
		options.remove("targetFormat");
		inputFilePath = options.get("inputFile");
		options.remove("inputFile");
		outputFilePath = options.get("outputFile");
		options.remove("outputFile");
		metadataFilePath = options.get("csv_metadata");
	}

	public String[] getCommandLine() {
		List<String> args = new ArrayList<String>();
		args.add("-"+format);
		for (String key: options.keySet()) {
			String value = options.get(key);
			if( value != null && !value.isEmpty()) {
				args.add("-"+key);
				args.add(value);
			}
		}
		args.add(inputFilePath);
		if (outputFilePath != null) {
			args.add(outputFilePath);
		}
		String sout = "";
		for (String val: args) {
			sout += val+" ";;
		}
		//Debug.printLog(sout, context);
		String[] array = args.toArray(new String[0]);
		return array; 
	}

	public boolean isValid() {
		if (format == null) {
			return false;
		}
		if (inputFilePath == null) {
			JOptionPane.showMessageDialog(frame, "Input file path is null");
			return false;
		}
		File inputFile = new File(inputFilePath);
		if (!inputFile.exists()) {
			JOptionPane.showMessageDialog(frame, "Input file not exists");
			return false;
		}
		if (!inputFile.canRead()){
			JOptionPane.showMessageDialog(frame, "Input file can not be read");
			return false;
		}
		if (metadataFilePath != null) {
			File metadataFile = new File(metadataFilePath);
			if (!metadataFile.exists()) {
				JOptionPane.showMessageDialog(frame, "Metadata file not exists");
				return false;
			}
			if (!metadataFile.canRead()) {
				JOptionPane.showMessageDialog(frame, "Metadata file can not be read");
				return false;
			}
		}
		if (outputFilePath == null) {
			File inputDir = inputFile.getParentFile();
			if (!inputDir.canWrite()) {
				JOptionPane.showMessageDialog(frame, "Output directory is not writable");
				return false;
			}
		} else {
			File outputFile = new File(outputFilePath);
			if (!outputFile.canWrite()) {
				if (outputFile.isDirectory()) {
					JOptionPane.showMessageDialog(frame, "Output directory is not writable");	
				} else {
					JOptionPane.showMessageDialog(frame, "Output file is not writable");
				}
				return false;
			}
		}

		return true;
	}

}
